@@ -7,6 +7,7 @@ except ImportError: # Django 1.5 compatibility
 from django.template.base import token_kwargs
 from django.template.loader import get_template
 from django.template.loader_tags import BlockNode, ExtendsNode, BlockContext
+from django.utils import six
 
 register = template.Library()
 
@@ -16,7 +17,7 @@ def resolve_blocks(template, context, blocks=None):
         blocks = BlockContext()
 
     # If it's just the name, resolve into template
-    if isinstance(template, basestring):
+    if isinstance(template, six.string_types):
         template = get_template(template)
 
     # Add this templates blocks as the first
@@ -116,12 +117,12 @@ def _auto_widget(field, context):
             '{field}',
         ):
         block = context['formulation'].get_block(
-            pattern.format(info)
+            pattern.format(**info)
         )
         if block is not None:
-            return block
-    raise TemplateSyntaxError("Could not find widget for field: %r" % field)
-    
+            break
+    return block
+
 
 @register.simple_tag(takes_context=True)
 def field(context, field, widget=None, **kwargs):
@@ -136,8 +137,12 @@ def field(context, field, widget=None, **kwargs):
         field_data[attr] = getattr(field.field, attr, None)
     kwargs.update(field_data)
     if widget is None:
-        widget = _auto_widget(field, context)
-    kwargs['block'] = block = context['formulation'].get_block(widget)
+        block = _auto_widget(field, context)
+    else:
+        block = context['formulation'].get_block(widget)
+    if block is None:
+        raise template.TemplateSyntaxError("Could not find widget for field: %r" % field)
+    kwargs['block'] = block
     with ContextDict(context, kwargs) as context:
         return block.render(context)
 
